@@ -13,13 +13,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .alertchart import AlertChart
+from .alertchart import (
+    AlertChart,
+)
+from .collapsible_group import (
+    CollapsibleGroup,
+)
 from .common import (
     Aggregation,
     PickTimeSeriesFilter,
     StatisticalTimeSeriesFilter,
 )
-from .dashboard import Dashboard
+from .dashboard import (
+    Dashboard,
+)
+from .dashboard_filter import (
+    DashboardFilter,
+)
 from .dashboards_service import (
     CreateDashboardRequest,
     DeleteDashboardRequest,
@@ -34,6 +44,9 @@ from .layouts import (
     MosaicLayout,
     RowLayout,
 )
+from .logs_panel import (
+    LogsPanel,
+)
 from .metrics import (
     Threshold,
     TimeSeriesFilter,
@@ -41,9 +54,21 @@ from .metrics import (
     TimeSeriesQuery,
     SparkChartType,
 )
-from .scorecard import Scorecard
-from .text import Text
-from .widget import Widget
+from .scorecard import (
+    Scorecard,
+)
+from .table import (
+    TimeSeriesTable,
+)
+from .table_display_options import (
+    TableDisplayOptions,
+)
+from .text import (
+    Text,
+)
+from .widget import (
+    Widget,
+)
 from .xychart import (
     ChartOptions,
     XyChart,
@@ -51,10 +76,12 @@ from .xychart import (
 
 __all__ = (
     "AlertChart",
+    "CollapsibleGroup",
     "Aggregation",
     "PickTimeSeriesFilter",
     "StatisticalTimeSeriesFilter",
     "Dashboard",
+    "DashboardFilter",
     "CreateDashboardRequest",
     "DeleteDashboardRequest",
     "GetDashboardRequest",
@@ -65,12 +92,15 @@ __all__ = (
     "GridLayout",
     "MosaicLayout",
     "RowLayout",
+    "LogsPanel",
     "Threshold",
     "TimeSeriesFilter",
     "TimeSeriesFilterRatio",
     "TimeSeriesQuery",
     "SparkChartType",
     "Scorecard",
+    "TimeSeriesTable",
+    "TableDisplayOptions",
     "Text",
     "Widget",
     "ChartOptions",
