@@ -20,7 +20,10 @@ from google.protobuf import duration_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
-    package="google.monitoring.dashboard.v1", manifest={"Scorecard",},
+    package="google.monitoring.dashboard.v1",
+    manifest={
+        "Scorecard",
+    },
 )
 
 
@@ -108,8 +111,14 @@ class Scorecard(proto.Message):
                 equal to this.
         """
 
-        lower_bound = proto.Field(proto.DOUBLE, number=1,)
-        upper_bound = proto.Field(proto.DOUBLE, number=2,)
+        lower_bound = proto.Field(
+            proto.DOUBLE,
+            number=1,
+        )
+        upper_bound = proto.Field(
+            proto.DOUBLE,
+            number=2,
+        )
 
     class SparkChartView(proto.Message):
         r"""A sparkChart is a small chart suitable for inclusion in a
@@ -132,23 +141,37 @@ class Scorecard(proto.Message):
         """
 
         spark_chart_type = proto.Field(
-            proto.ENUM, number=1, enum=metrics.SparkChartType,
+            proto.ENUM,
+            number=1,
+            enum=metrics.SparkChartType,
         )
         min_alignment_period = proto.Field(
-            proto.MESSAGE, number=2, message=duration_pb2.Duration,
+            proto.MESSAGE,
+            number=2,
+            message=duration_pb2.Duration,
         )
 
     time_series_query = proto.Field(
-        proto.MESSAGE, number=1, message=metrics.TimeSeriesQuery,
+        proto.MESSAGE,
+        number=1,
+        message=metrics.TimeSeriesQuery,
     )
     gauge_view = proto.Field(
-        proto.MESSAGE, number=4, oneof="data_view", message=GaugeView,
+        proto.MESSAGE,
+        number=4,
+        oneof="data_view",
+        message=GaugeView,
     )
     spark_chart_view = proto.Field(
-        proto.MESSAGE, number=5, oneof="data_view", message=SparkChartView,
+        proto.MESSAGE,
+        number=5,
+        oneof="data_view",
+        message=SparkChartView,
     )
     thresholds = proto.RepeatedField(
-        proto.MESSAGE, number=6, message=metrics.Threshold,
+        proto.MESSAGE,
+        number=6,
+        message=metrics.Threshold,
     )
 
 
